@@ -7,10 +7,9 @@ use warnings;
 # NOTE: Now we've switched to Sub::Uplevel can this be removed? --ADAMK
 use Carp::Heavy     (); 
 use Carp            ();
-use Aspect::Cleanup ();
 use Aspect::Advice  ();
 
-our $VERSION = '0.24';
+our $VERSION = '0.25';
 our @ISA     = 'Aspect::Advice';
 
 sub new {
@@ -24,7 +23,7 @@ sub type {
 	return 'before';
 }
 
-sub install {
+sub _install {
 	my $self     = shift;
 	my $pointcut = $self->pointcut;
 	my $code     = $self->code;
@@ -72,7 +71,7 @@ sub install {
 				type         => 'before',
 				pointcut     => $pointcut,
 				sub_name     => $name,
-				# wantarray    => $wantarray,
+				wantarray    => $wantarray,
 				params       => \@_,
 				return_value => $wantarray ? [ ] : undef,
 				original     => $original,
@@ -118,8 +117,11 @@ sub install {
 		die $@ if $@;
 	}
 
-	# Return the lexical hook
-	return Aspect::Cleanup->new( sub { $out_of_scope = 1 } );
+	# Return the lexical descoping hook.
+	# This MUST be stored and run at DESTROY-time by the
+	# parent object calling _install. This is less bullet-proof
+	# than the DESTROY-time self-executing blessed coderef
+	return sub { $out_of_scope = 1 };
 }
 
 1;
